hi_profanity = [
    "behenchod", "madarchod", "gandu", "chut", "chutiyapa", "bhosdike",
    "bhenchot", "gand", "gandmasti", "gandmar", "gandmard", "gandmardi",
    "gandmard", "gandmardi", "gandmard", "gandmardi", "gandmard", "gandmardi",
]